aacgmv2
=======

These functions are available when you ``import aacgmv2``.

.. automodule:: aacgmv2
    :members:


aacgmv2.wrapper
---------------

.. automodule:: aacgmv2.wrapper
    :members:


aacgmv2.utils
-------------
  
.. automodule:: aacgmv2.utils
    :members:
		
